#!/bin/bash
VER=1.0
###################################################
# Tur-DirClean. For a nice and updated search     #
# function in glftpd. Keep the dirlog up to date! #
# All this script really does, is                 #
# 1: Run olddirclean2, thus removing all releases #
#    that is not on the site anymore.             #
# 2: Run glupdate on every section you define,    #
#    updating with what is there now. Works for   #
#    dated dirs too.                              #
#--[ Installation ]-------------------------------#
#                                                 #
# Copy this script to where ever (/glftpd/bin).   #
# Make it executable (chmod 755 tur-dirclean.sh). #
# Edit the settings:                              #
#                                                 #
# glconf=  Full path to your glftpd.conf file.    #
#                                                 #
# cleanold=  What to run to clean out old folders #
#            that are not there anymore.          #
#            If you havent, put olddirclean2 from #
#            glftpd in /glftpd/bin.               #
#                                                 #
# cleanlog=  Where to log to. Only one day will   #
#            be logged at a time (no point to log #
#            more stuff).                         #
#                                                 #
# glupdate=  Where is glupdate? As with           #
#            olddirclean2, this comes with glftpd #
#            and should be working from shell.    #
#                                                 #
# sections=  Specify each section on your site    #
#            that you want to search for releases #
#            in. Add :DEEP to the end to dive one #
#            folder into that (for dated dirs).   #
#                                                 #
# exclude=   This is only if you specify :DEEP    #
#            What NOT to add to dirlog? Pre       #
#            folders, !today symlinks, .message   #
#            file, etc etc. Anything that can be  #
#            in the folders, but does not belong  #
#            in the dirlog.                       #
#                                                 #
# Try it by adding a folder from shell in any of  #
# the sections. Then search for it with           #
# site search and make sure it does not find it.  #
# Run this script and try and search for it again.#
#                                                 #
# Crontab this script to run whenever you like.   #
# like:                                           #
# 1 1 * * * /glftpd/bin/tur-dirclean.sh           #
# to run it 01:01AM each day.                     #
#-[ Contact ]-------------------------------------#
#                                                 #
# IRC: Turranius/Turran on efnet. Usually #glftpd #
# WEB: http://www.grandis.nu &                    #
#      http://grandis.mine.nu                     #
# EMAIL: turranius@hotmail.com                    #
#-[ Settings ]------------------------------------#

glconf="/etc/glftpd.conf"

cleanold="/glftpd/bin/olddirclean2 -P -D"
cleanlog="/glftpd/ftp-data/logs/olddirclean.log"

glupdate="/glftpd/bin/glupdate"

sections="
/glftpd/site/DIVX
/glftpd/site/SVCD
/glftpd/site/0DAYS:DEEP
/glftpd/site/MP3:DEEP
"

exclude='GROUPS|!Today|!Yesterday|.message'


###################################################
# No changes below here                           #
###################################################

## Run olddircleaner.
$cleanold > $cleanlog

echo "" >> $cleanlog

for section in $sections; do
  dated="$( echo $section | awk -F":" '{print $2}' )"
  if [ "$dated" != "DEEP" ]; then
    $glupdate -r $glconf $section >> $cleanlog
  else
    section="$( echo $section | awk -F":" '{print $1}' )"
    cd $section
    LIST="$( ls -f -A | egrep -v $exclude )"
    for folder in $LIST; do
      $glupdate -r $glconf $section/$folder >> $cleanlog
    done
  fi
done

exit 0